# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`fetchcrl`](#fetchcrl): Main class, installs fetch-crl and configures it.

#### Private Classes

* `fetchcrl::config`: Configures fetch-crl
* `fetchcrl::install`: Installs fetch-crl
* `fetchcrl::service`: Controls fetch-crl cron or timer.

### Defined types

* [`fetchcrl::ca`](#fetchcrl--ca): Creates per CA configuration files.

## Classes

### <a name="fetchcrl"></a>`fetchcrl`

fetchcrl

* **See also**
  * https://wiki.nikhef.nl/grid/FetchCRL3
    * FetchCRL3

#### Examples

##### Simple Example

```puppet
class{'fetchcrl':
  http_proxy            => 'http:://squid.example.org:8000',
  carepo                => 'http://yum.example.org/yumrepo',
  cache_control_request => '3600',
}
```

##### A hash of particular CA configurations

```puppet
class{'fetchcrl':
  cas => {
    'EDG-Tutorial-CA' => {
      'agingtolerance' => 168,
     }
     'MD-Grid-CA-T'   => {
      'noerrors'       => true,
     }
    }
  }
}
```

#### Parameters

The following parameters are available in the `fetchcrl` class:

* [`capkgs`](#-fetchcrl--capkgs)
* [`carepo`](#-fetchcrl--carepo)
* [`carepo_gpgkey`](#-fetchcrl--carepo_gpgkey)
* [`manage_carepo`](#-fetchcrl--manage_carepo)
* [`capkgs_version`](#-fetchcrl--capkgs_version)
* [`pkg_version`](#-fetchcrl--pkg_version)
* [`agingtolerance`](#-fetchcrl--agingtolerance)
* [`nosymlinks`](#-fetchcrl--nosymlinks)
* [`inet6glue`](#-fetchcrl--inet6glue)
* [`noerrors`](#-fetchcrl--noerrors)
* [`nowarnings`](#-fetchcrl--nowarnings)
* [`http_proxy`](#-fetchcrl--http_proxy)
* [`httptimeout`](#-fetchcrl--httptimeout)
* [`parallelism`](#-fetchcrl--parallelism)
* [`logmode`](#-fetchcrl--logmode)
* [`pkgname`](#-fetchcrl--pkgname)
* [`runcron`](#-fetchcrl--runcron)
* [`runboot`](#-fetchcrl--runboot)
* [`randomcron`](#-fetchcrl--randomcron)
* [`cache_control_request`](#-fetchcrl--cache_control_request)
* [`cas`](#-fetchcrl--cas)

##### <a name="-fetchcrl--capkgs"></a>`capkgs`

Data type: `Array[String[1]]`

CA policy packages to install.

Default value: `['ca-policy-egi-core']`

##### <a name="-fetchcrl--carepo"></a>`carepo`

Data type: `Stdlib::Httpurl`

Repository URL of CA packages.

Default value: `'https://repository.egi.eu/sw/production/cas/1/current/'`

##### <a name="-fetchcrl--carepo_gpgkey"></a>`carepo_gpgkey`

Data type: `Stdlib::Httpurl`

Repository URL of GPG key for CA packages.

Default value: `'https://dist.eugridpma.info/distribution/igtf/current/GPG-KEY-EUGridPMA-RPM-3'`

##### <a name="-fetchcrl--manage_carepo"></a>`manage_carepo`

Data type: `Boolean`

Should package repository be configured.

Default value: `true`

##### <a name="-fetchcrl--capkgs_version"></a>`capkgs_version`

Data type: `String`

Version of CA packages.

Default value: `'present'`

##### <a name="-fetchcrl--pkg_version"></a>`pkg_version`

Data type: `String`

Version of fetch-crl package.

Default value: `'present'`

##### <a name="-fetchcrl--agingtolerance"></a>`agingtolerance`

Data type: `Integer`

Number of hours delay time before errors are generated in case downloads consistently fail.

Default value: `24`

##### <a name="-fetchcrl--nosymlinks"></a>`nosymlinks`

Data type: `Boolean`

Do not create serial number symlinks.

Default value: `true`

##### <a name="-fetchcrl--inet6glue"></a>`inet6glue`

Data type: `Boolean`

use Net::INET6Glue , parameter is ignored on RedHat 9 or Debian 12 and newer.

Default value: `false`

##### <a name="-fetchcrl--noerrors"></a>`noerrors`

Data type: `Boolean`

Do not produce errors.

Default value: `false`

##### <a name="-fetchcrl--nowarnings"></a>`nowarnings`

Data type: `Boolean`

Do not produce warnings.

Default value: `true`

##### <a name="-fetchcrl--http_proxy"></a>`http_proxy`

Data type: `Optional[Stdlib::Httpurl]`

http proxy URLs. For example http://foobar.example.org:3218/

Default value: `undef`

##### <a name="-fetchcrl--httptimeout"></a>`httptimeout`

Data type: `Integer`

Time out for http.

Default value: `30`

##### <a name="-fetchcrl--parallelism"></a>`parallelism`

Data type: `Integer`

Number of fetchs to run concurrently.

Default value: `4`

##### <a name="-fetchcrl--logmode"></a>`logmode`

Data type: `Enum['direct','qualified', 'cache','syslog']`

Specify how logging is done.

Default value: `'syslog'`

##### <a name="-fetchcrl--pkgname"></a>`pkgname`

Data type: `String[1]`

Name of fetch-crl package.

Default value: `'fetch-crl'`

##### <a name="-fetchcrl--runcron"></a>`runcron`

Data type: `Boolean`

Should fetch-crl be run periodically either as a cron job or timer as appropriate.

Default value: `true`

##### <a name="-fetchcrl--runboot"></a>`runboot`

Data type: `Boolean`

Should fetch-crl be run at boot time.
This parameter is only significant for fetch-crl packages
that use a cron based package and not a systemd timer.

Default value: `false`

##### <a name="-fetchcrl--randomcron"></a>`randomcron`

Data type: `Boolean`

Should the every 6 hour cron be configured with a random offset.
With osfamily RedHat 8 or newer the randomcron parameter is ignored.
The systemd timer for fetch-crl is already very random.

Default value: `true`

##### <a name="-fetchcrl--cache_control_request"></a>`cache_control_request`

Data type: `Optional[Integer]`

Sends a cache-control max-age hint in seconds towards the server in the HTTP request.

Default value: `undef`

##### <a name="-fetchcrl--cas"></a>`cas`

Data type: `Optional[Hash]`

A hash of `fetchcrl::ca` defined types to load.

Default value: `undef`

## Defined types

### <a name="fetchcrl--ca"></a>`fetchcrl::ca`

Creates per CA configuration files.

#### Examples

##### Simple Example

```puppet
fetchcrl::ca{'EDG-Tutorial-CA':
  agingtolerance => 168,
  comment        => 'Increased as unreliable',
}
```

#### Parameters

The following parameters are available in the `fetchcrl::ca` defined type:

* [`name`](#-fetchcrl--ca--name)
* [`anchorname`](#-fetchcrl--ca--anchorname)
* [`nowarnings`](#-fetchcrl--ca--nowarnings)
* [`noerrors`](#-fetchcrl--ca--noerrors)
* [`httptimeout`](#-fetchcrl--ca--httptimeout)
* [`agingtolerance`](#-fetchcrl--ca--agingtolerance)
* [`comment`](#-fetchcrl--ca--comment)
* [`crl_url`](#-fetchcrl--ca--crl_url)

##### <a name="-fetchcrl--ca--name"></a>`name`

The name of the CA to manage a configuration for.

##### <a name="-fetchcrl--ca--anchorname"></a>`anchorname`

Data type: `String[1]`

The name of the CA to manage a configuration for.

Default value: `$title`

##### <a name="-fetchcrl--ca--nowarnings"></a>`nowarnings`

Data type: `Boolean`

Should warnings be supressed for this CA.

Default value: `false`

##### <a name="-fetchcrl--ca--noerrors"></a>`noerrors`

Data type: `Boolean`

Should errors be supressed for this CA.

Default value: `false`

##### <a name="-fetchcrl--ca--httptimeout"></a>`httptimeout`

Data type: `Optional[Integer]`

The timeout for this CA.

Default value: `undef`

##### <a name="-fetchcrl--ca--agingtolerance"></a>`agingtolerance`

Data type: `Optional[Integer]`

The delay if failures before it is considered an error.

Default value: `undef`

##### <a name="-fetchcrl--ca--comment"></a>`comment`

Data type: `Optional[String[1]]`

Add a comment to the particular CA configuration

Default value: `undef`

##### <a name="-fetchcrl--ca--crl_url"></a>`crl_url`

Data type: `Array[Stdlib::Httpurl]`

A list of URLs to download CAs from

Default value: `[]`

